mercurial/merge.py
changeset 37762 7269b87f817c
parent 37172 daef13da66fe
child 37959 000039f6ca2d
child 38425 1322ae04d3d7
--- a/mercurial/merge.py	Mon Apr 16 23:39:30 2018 -0400
+++ b/mercurial/merge.py	Sat Apr 14 18:50:45 2018 -0400
@@ -1465,7 +1465,7 @@
         yield i, f
 
 def _prefetchfiles(repo, ctx, actions):
     """Invoke ``scmutil.fileprefetchhooks()`` for the files relevant to the dict
     of merge actions.  ``ctx`` is the context being merged in."""
 
     # Skipping 'a', 'am', 'f', 'r', 'dm', 'e', 'k', 'p' and 'pr', because they
@@ -1473,8 +1473,11 @@
     # changed/deleted never resolves to something from the remote side.
     oplist = [actions[a] for a in (ACTION_GET, ACTION_DELETED_CHANGED,
                                    ACTION_LOCAL_DIR_RENAME_GET, ACTION_MERGE)]
-    prefetch = scmutil.fileprefetchhooks
-    prefetch(repo, ctx, [f for sublist in oplist for f, args, msg in sublist])
+    prefetch = scmutil.prefetchfiles
+    matchfiles = scmutil.matchfiles
+    prefetch(repo, [ctx.rev()],
+             matchfiles(repo,
+                        [f for sublist in oplist for f, args, msg in sublist]))
 
 @attr.s(frozen=True)
 class updateresult(object):
@@ -1465,7 +1465,7 @@
 
 def _prefetchfiles(repo, ctx, actions):
-    """Invoke ``scmutil.fileprefetchhooks()`` for the files relevant to the dict
+    """Invoke ``scmutil.prefetchfiles()`` for the files relevant to the dict
     of merge actions.  ``ctx`` is the context being merged in."""
 